@@ -118,40 +118,3 @@ posterior_predict.pandemicEstimated = function(object, horizonLong = 500, horizo
   class(output) = "pandemicPredicted"
   return(output)
 }
-
-# Auxiliary function for posterior_predict.pandemicEstimated
-# Provides the actual predictions
-# c for chains, h for horizon, n for NA value, m for model, ft for final time and s for seasonal effects days
-#' @importFrom stats rpois rgamma pnorm
-generatePredictedPoints_pandemic = function(M,c,h,n,m,ft,s){
-
-  .Deprecated("generatePredictedPoints_pandemicC")
-  y = mu = matrix(-Inf,ncol = h,nrow = M)
-  if (m == "poisson: static generalized logistic")
-    for (i in 1:h){
-      mu[,i] = exp(log(c$f)+log(c$a)+log(c$c)-(c$c*(ft+i))-(c$f+1)*log(c$b+exp(-c$c*(ft+i)) ))
-      y[,i] = stats::rpois(M,mu[,i])
-    } else if (m == "negbin: static generalized logistic")
-    for (i in 1:h){
-      mu[,i] = exp(log(c$f)+log(c$a)+log(c$c)-(c$c*(ft+i))-(c$f+1)*log(c$b+exp(-c$c*(ft+i)) ))
-      y[,i] = stats::rpois(M,stats::rgamma(M,mu[,i]*c$phi,c$phi))
-    } else if (m == "poisson: static seasonal generalized logistic"){
-      d_1 = c$d_1; d_2 = ifelse(is.null(c$d_2),1,c$d_2); d_3 = ifelse(is.null(c$d_3),1,c$d_3)
-    for (i in 1:h){
-      mu[,i] = exp(log(c$f)+log(c$a)+log(c$c)-(c$c*(ft+i))-(c$f+1)*log(c$b+exp(-c$c*(ft+i)) ))*
-        d_1^((s[1]>0) * !((ft+i - s[1]) %% 7)) * d_2^((s[2]>0) * !((ft+i - s[2]) %% 7)) * d_3^((s[3]>0) * !((ft+i - s[3]) %% 7))
-      y[,i] = stats::rpois(M,mu[,i])
-    }} else if (m == "poisson: multi_waves(2)")
-    for (i in 1:h){
-      mu[,i] = exp(log(c$a1)+log(c$c1)-(c$c1*(ft+i))-2*log(c$b1+exp(-c$c1*(ft+i)) ) + stats::pnorm(c$alpha1*(ft+i-c$delta1),log.p = TRUE))+
-          exp(log(c$a2)+log(c$c2)-(c$c2*(ft+i))-2*log(c$b2+exp(-c$c2*(ft+i)) ) + stats::pnorm(c$alpha2*(ft+i-c$delta2),log.p = TRUE))
-      y[,i] = stats::rpois(M,mu[,i])
-    } else stop(paste("Unknown model",m))
-
-  if (any(is.na(y))){
-    message(paste("Prediction had",sum(is.na(y)),"NA values. Replaced with large value for identification."))
-    y.fut[is.na(y.fut)] = n
-  }
-
-  list(yL=y, yS = t(apply(y,1,cumsum)), mu = mu)
-}
